#
# Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
# Ministerpräsidenten des Landes Schleswig-Holstein
# Staatskanzlei
# Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
#
# Lizenziert unter der EUPL, Version 1.2 oder - sobald
# diese von der Europäischen Kommission genehmigt wurden -
# Folgeversionen der EUPL ("Lizenz");
# Sie dürfen dieses Werk ausschließlich gemäß
# dieser Lizenz nutzen.
# Eine Kopie der Lizenz finden Sie hier:
#
# https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
#
# Sofern nicht durch anwendbare Rechtsvorschriften
# gefordert oder in schriftlicher Form vereinbart, wird
# die unter der Lizenz verbreitete Software "so wie sie
# ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
# ausdrücklich oder stillschweigend - verbreitet.
# Die sprachspezifischen Genehmigungen und Beschränkungen
# unter der Lizenz sind dem Lizenztext zu entnehmen.
#

{{/* vim: set filetype=mustache: */}}

{{/* Namespace */}}
{{- define "app.namespace" -}}
{{- if gt (len (.Release.Namespace)) 63 -}}
{{- fail (printf ".Release.Namespace %s ist zu lang (max. 63 Zeichen)" .Release.Namespace) -}}
{{- end -}}
{{ printf "%s" .Release.Namespace }}
{{- end -}}

{{/* Chart: Name + Version */}}
{{- define "app.chart" -}}
{{- if gt (len (printf "%s-%s" .Chart.Name .Chart.Version)) 63 -}}
{{- fail (printf ".Chart.Name-.Chart.Version %s-%s ist zu lang (max. 63 Zeichen)" .Chart.Name .Chart.Version) -}}
{{- end -}}
{{ printf "%s-%s" .Chart.Name .Chart.Version }}
{{- end -}}

{{/* Managed-by -> On Helm, this value is always Helm */}}
{{- define "app.managedBy" -}}
{{- if gt (len (.Release.Service)) 63 -}}
{{- fail (printf ".Release.Service %s ist zu lang (max. 63 Zeichen)" .Release.Service) -}}
{{- end -}}
{{ printf "%s" .Release.Service }}
{{- end -}}

{{/* Default Labels: Helm recommended best-practice labels https://helm.sh/docs/chart_best_practices/labels/ */}}
{{- define "app.defaultLabels" }}
app.kubernetes.io/instance: user-manager
app.kubernetes.io/managed-by: {{ include "app.managedBy" . }}
app.kubernetes.io/name: {{ .Release.Name }}
app.kubernetes.io/namespace: {{ include "app.namespace" . }}
app.kubernetes.io/part-of: ozgcloud
app.kubernetes.io/version: {{ .Chart.Version }}
helm.sh/chart: {{ include "app.chart" . }}
ozgcloud-mongodb-client: "true"
{{- end -}}

{{- define "app.matchLabels" }}
app.kubernetes.io/name: {{ .Release.Name }}
app.kubernetes.io/namespace: {{ include "app.namespace" . }}
{{- end -}}

{{- define "app.cronjobScheduler" }}
{{- printf "%d %d * * *" (div (randNumeric 2) 2) (div (randNumeric 1) 2) -}}
{{- end -}}

{{- define "app.ozgcloudEnvironment" -}}
{{- required "Environment muss angegeben sein" (.Values.ozgcloud).environment -}}
{{- end -}}

{{- define "app.ssoServerUrl" -}}
{{- if contains "https://" (required "sso.serverUrl must be set" (.Values.sso).serverUrl) -}}
{{- .Values.sso.serverUrl -}}
{{- else -}}
{{- printf "https://%s" .Values.sso.serverUrl -}}
{{- end -}}
{{- end -}}

{{- define "app.ozgcloudBundesland" -}}
{{- required "ozgcloud.bundesland must be set " (.Values.ozgcloud).bundesland }}
{{- end -}}

{{- define "app.ozgcloudBezeichner" -}}
{{- if (.Values.ozgcloud).bezeichner -}}

{{ $length := len (.Values.ozgcloud).bezeichner }}
{{- if lt 46 $length -}}
{{ required (printf "Bezeichner %s ist zu lang (max. 46 Zeichen)" (.Values.ozgcloud).bezeichner) nil }}
{{- else -}}
{{- required "Bezeichner muss angegeben sein" (.Values.ozgcloud).bezeichner -}}
{{- end -}}
{{- else -}}
{{- required "Bezeichner muss angegeben sein" (.Values.ozgcloud).bezeichner -}}
{{- end -}}
{{- end -}}

{{- define "app.ssoRealm" -}}
{{ printf "%s-%s-%s" (include "app.ozgcloudBundesland" .) ( include "app.ozgcloudBezeichner" . ) ( include "app.ozgcloudEnvironment" . ) | trunc 63 | trimSuffix "-" }}
{{- end -}}

{{- define "app.ssoClientName" -}}
{{- if (.Values.sso).client_name -}}
{{ printf "%s" (.Values.sso).client_name }}
{{- else -}}
{{ printf "alfa" }}
{{- end -}}
{{- end -}}

{{- define "app.baseUrl" -}}
{{- required "baseUrl muss angegeben sein" .Values.baseUrl }}
{{- end -}}

{{- define "app.baseDomain" -}}
{{- if (.Values.baseDomain) -}}
{{ .Values.baseDomain }}
{{- else -}}
{{ printf "%s-%s.%s" (include "app.ozgcloudBezeichner" .) (.Release.Name) (include "app.baseUrl" .) }}
{{- end -}}
{{- end -}}

{{- define "app.alfaAddress" -}}
{{ printf "https://%s.%s" (include "app.ozgcloudBezeichner" .) (required "baseUrl must be set" .Values.baseUrl) }}
{{- end -}}

{{- define "app.replaceAllNonAlphanumeric" -}}
{{- regexReplaceAll "[^a-zA-Z0-9]" . "" }}
{{- end -}}

{{- define "app.generateKeycloakUserRessourceName" -}}
{{- $lowerUserName := .Values.sso.api_user.name | lower }}
{{- $alphanumericUserName :=  (include "app.replaceAllNonAlphanumeric" $lowerUserName ) }}
{{- printf "%s-keycloak-user"  ( $alphanumericUserName | trunc 20) }}
{{- end -}}

{{- define "app.generateKeycloakUserSecretName" -}}
{{- $lowerUserName := .Values.sso.api_user.name | lower }}
{{- $alphanumericUserName :=  (include "app.replaceAllNonAlphanumeric" $lowerUserName ) }}
{{- printf "%s-credentials"  ( $alphanumericUserName | trunc 20) }}
{{- end -}}

{{- define "app.databaseSecretName" -}}
{{- if (.Values.database).secretName -}}
{{  .Values.database.secretName }}
{{- else -}}
{{  printf "ozg-mongodb-admin-user-manager-user" }}
{{- end -}}
{{- end -}}

{{- define "app.databaseName" -}}
{{- if (.Values.database).databaseName -}}
{{  .Values.database.databaseName }}
{{- else -}}
{{ printf "user-manager-database" }}
{{- end -}}
{{- end -}}

{{- define "app.serviceAccountName" -}}
{{ printf "%s" ( (.Values.serviceAccount).name | default "user-manager-service-account" ) }}
{{- end -}}

{{- define "app.truststoreSecretName" -}}
{{- if .Values.optionalTrustStoreSecretName -}}
{{ .Values.optionalTrustStoreSecretName }}
{{- else -}}
{{ printf "user-manager-truststore" }}
{{- end -}}
{{- end -}}

{{- define "app.getCustomList" -}}
{{- with (.Values.env).customList -}}
{{- if kindIs "map" . -}}
{{ include "app.dictToList" . }}
{{- else if kindIs "slice" . -}}
{{ . | toYaml }}
{{- end -}}
{{- end -}}
{{- end -}}

{{- define "app.dictToList" -}}
{{- $customList := list -}}
{{- range $key, $value := . -}}
{{- $customList = append $customList (dict "name" $key "value" $value) }}
{{- end -}}
{{- $customList | toYaml -}}
{{- end -}}