/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user.common.callcontext;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import java.io.IOException;

import jakarta.ws.rs.container.ContainerRequestContext;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;

import de.ozgcloud.user.common.JwtUtil;

class HttpSecurityFilterTest {

	@Spy
	@InjectMocks
	private HttpSecurityFilter securityFilter;
	@Mock
	private CurrentCallContextUserService contextUserService;
	@Mock
	private JwtUtil jwtUtil;

	@DisplayName("Filter")
	@Nested
	class TestFilter {

		@Mock
		private ContainerRequestContext requestContext;

		@BeforeEach
		void init() {
			doReturn(CallContextUserTestFactory.create()).when(securityFilter).buildCallContextUser();
		}

		@Test
		void shouldBuildCallContextUser() throws IOException {
			securityFilter.filter(requestContext);

			verify(securityFilter).buildCallContextUser();
		}

		@Test
		void shouldSetCallContextUser() throws IOException {
			securityFilter.filter(requestContext);

			verify(contextUserService).setCallContextUser(any());
		}
	}

	@DisplayName("Build call context user")
	@Nested
	class TestBuildCallContextUser {

		@Test
		void shouldBeAuthenticated() {
			var user = securityFilter.buildCallContextUser();

			assertThat(user.isAuthenticated()).isTrue();
		}

		@Test
		void shouldGetUserId() {
			securityFilter.buildCallContextUser();

			verify(jwtUtil).getUserId();
		}

		@Test
		void shouldGetUserName() {
			securityFilter.buildCallContextUser();

			verify(jwtUtil).getUserName();
		}

		@Test
		void shouldGetEmail() {
			securityFilter.buildCallContextUser();

			verify(jwtUtil).getEmail();
		}

		@Test
		void shouldGetRoles() {
			securityFilter.buildCallContextUser();

			verify(jwtUtil).getUserRoles();
		}

		@Test
		void shouldGetOrganistaionsEinheitenIds() {
			securityFilter.buildCallContextUser();

			verify(jwtUtil).getOrganisationsEinheitIds();
		}
	}
}